Learn R Programming

telescope (version 0.2-1)

priorOnE0_spec: Specify prior on e0.

Description

Obtain a function to evaluate the log prior specified for \(e_0\).

Usage

priorOnE0_spec(E = c("G_1_20", "e0const"), e0)

Value

A named list containing:

  • "log_p_e0": a function of the log prior of \(e_0\).

  • "param": a list with the parameters.

Arguments

E

A character indicating which specification should be used.

e0

A numeric scalar giving the fixed value of \(e_0\).

Details

The following prior specifications are supported:

  • "G_1_20": \(e_0 \sim\) gamma(1, 20), i.e., shape = 1, rate = 20.

  • "e0const": \(e_0\) is fixed at e0.