Obtain a function to evaluate the log prior specified for \(e_0\).
priorOnE0_spec(E = c("G_1_20", "e0const"), e0)A named list containing:
"log_p_e0": a function of the log prior of \(e_0\).
"param": a list with the parameters.
A character indicating which specification should be used.
A numeric scalar giving the fixed value of \(e_0\).
The following prior specifications are supported:
"G_1_20": \(e_0 \sim\) gamma(1, 20), i.e., shape = 1, rate = 20.
"e0const": \(e_0\) is fixed at e0.